# 致谢

在最初编写AcmeN时，参考了[`Trim/acme-dns-tiny`](https://github.com/Trim/acme-dns-tiny/) 的实现方法，向作者表示感谢。

AcmeN使用了以下第三方Python库：

- [dnspython](https://www.dnspython.org/)
- [requests](https://github.com/psf/requests)
- [tld](https://github.com/barseghyanartur/tld)
- [jwcrypto](https://github.com/latchset/jwcrypto)
- [cryptography](https://cryptography.io)

AcmeN文档使用[`mkdocs`](https://www.mkdocs.org)渲染。

感谢开源社区提供的支持。
